Contributor Code of Conduct
===========================

As contributors and maintainers of the Dragonfly project, we pledge to
respect everyone who contributes by posting issues, updating
documentation, submitting pull requests, providing feedback in comments,
and any other activities.

Communication through any of Dragonfly’s channels (GitHub, Discord,
Gitter, mailing lists, etc.) must be constructive and never resort to
personal attacks, trolling, public or private harassment, insults, or
other unprofessional conduct.

We promise to extend courtesy and respect to everyone involved in this
project regardless of gender, gender identity, sexual orientation,
disability, age, race, ethnicity, religion, or level of experience. We
expect anyone contributing to the Dragonfly project to do the same.

If any member of the community violates this code of conduct, the
maintainers of the Dragonfly project may take action, removing issues,
comments, and PRs or blocking accounts as deemed appropriate.

If you are subject to or witness unacceptable behavior, or have any
other concerns, please email the project maintainer at
Danesprite@posteo.net.

This *Contributor Code of Conduct* has been adapted from
`Angular's Contributor Code of Conduct
<https://github.com/angular/angular/blob/master/CODE_OF_CONDUCT.md>`__
(Version 0.3b-angular).
